==> com.liferay.headless.admin.user.impl-3.0.85-sources.jar: com/liferay/headless/admin/user/internal/resource/v1_0/SubscriptionResourceImpl.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.headless.admin.user.internal.resource.v1_0;

import com.liferay.headless.admin.user.dto.v1_0.Subscription;
import com.liferay.headless.admin.user.resource.v1_0.SubscriptionResource;
import com.liferay.portal.vulcan.pagination.Page;
import com.liferay.portal.vulcan.pagination.Pagination;
import com.liferay.subscription.service.SubscriptionLocalService;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;
import org.osgi.service.component.annotations.ServiceScope;

/**
 * @author Javier Gamarra
 */
@Component(
	properties = "OSGI-INF/liferay/rest/v1_0/subscription.properties",
	scope = ServiceScope.PROTOTYPE, service = SubscriptionResource.class
)
public class SubscriptionResourceImpl extends BaseSubscriptionResourceImpl {

	@Override
	public void deleteMyUserAccountSubscription(Long subscriptionId)
		throws Exception {

		_subscriptionLocalService.deleteSubscription(subscriptionId);
	}

	@Override
	public Subscription getMyUserAccountSubscription(Long subscriptionId)
		throws Exception {

		return _toSubscription(
			_subscriptionLocalService.getSubscription(subscriptionId));
	}

	@Override
	public Page<Subscription> getMyUserAccountSubscriptionsPage(
		String contentType, Pagination pagination) {

		long userId = contextUser.getUserId();

		if (contentType != null) {
			return Page.of(
				transform(
					_subscriptionLocalService.getUserSubscriptions(
						userId, contentType),
					this::_toSubscription));
		}

		return Page.of(
			transform(
				_subscriptionLocalService.getUserSubscriptions(
					userId, pagination.getStartPosition(),
					pagination.getEndPosition(), null),
				this::_toSubscription),
			pagination,
			_subscriptionLocalService.getUserSubscriptionsCount(userId));
	}

	private Subscription _toSubscription(
		com.liferay.subscription.model.Subscription subscription) {

		return new Subscription() {
			{
				contentId = subscription.getClassPK();
				contentType = subscription.getClassName();
				dateCreated = subscription.getCreateDate();
				dateModified = subscription.getModifiedDate();
				frequency = subscription.getFrequency();
				id = subscription.getSubscriptionId();
				siteId = subscription.getGroupId();
			}
		};
	}

	@Reference
	private SubscriptionLocalService _subscriptionLocalService;

}

==> com.liferay.headless.admin.user.impl-5.0.72-sources.jar: com/liferay/headless/admin/user/internal/resource/v1_0/SubscriptionResourceImpl.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.headless.admin.user.internal.resource.v1_0;

import com.liferay.headless.admin.user.dto.v1_0.Subscription;
import com.liferay.headless.admin.user.resource.v1_0.SubscriptionResource;
import com.liferay.portal.vulcan.dto.converter.DTOConverter;
import com.liferay.portal.vulcan.dto.converter.DTOConverterRegistry;
import com.liferay.portal.vulcan.pagination.Page;
import com.liferay.portal.vulcan.pagination.Pagination;
import com.liferay.subscription.service.SubscriptionLocalService;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;
import org.osgi.service.component.annotations.ServiceScope;

/**
 * @author Javier Gamarra
 */
@Component(
	properties = "OSGI-INF/liferay/rest/v1_0/subscription.properties",
	scope = ServiceScope.PROTOTYPE, service = SubscriptionResource.class
)
public class SubscriptionResourceImpl extends BaseSubscriptionResourceImpl {

	@Override
	public void deleteMyUserAccountSubscription(Long subscriptionId)
		throws Exception {

		_subscriptionLocalService.deleteSubscription(subscriptionId);
	}

	@Override
	public Subscription getMyUserAccountSubscription(Long subscriptionId)
		throws Exception {

		return _toSubscription(
			_subscriptionLocalService.getSubscription(subscriptionId));
	}

	@Override
	public Page<Subscription> getMyUserAccountSubscriptionsPage(
		String contentType, Pagination pagination) {

		long userId = contextUser.getUserId();

		if (contentType != null) {
			return Page.of(
				transform(
					_subscriptionLocalService.getUserSubscriptions(
						userId, _getDTOClassName(contentType)),
					this::_toSubscription));
		}

		return Page.of(
			transform(
				_subscriptionLocalService.getUserSubscriptions(
					userId, pagination.getStartPosition(),
					pagination.getEndPosition(), null),
				this::_toSubscription),
			pagination,
			_subscriptionLocalService.getUserSubscriptionsCount(userId));
	}

	private String _getDTOClassName(String contentType) {
		for (String dtoClassName : _dtoConverterRegistry.getDTOClassNames()) {
			DTOConverter<?, ?> dtoConverter =
				_dtoConverterRegistry.getDTOConverter(dtoClassName);

			if (contentType.equals(dtoConverter.getContentType())) {
				return dtoConverter.getDTOClassName();
			}
		}

		return contentType;
	}

	private Subscription _toSubscription(
		com.liferay.subscription.model.Subscription subscription) {

		return new Subscription() {
			{
				contentId = subscription.getClassPK();
				dateCreated = subscription.getCreateDate();
				dateModified = subscription.getModifiedDate();
				frequency = subscription.getFrequency();
				id = subscription.getSubscriptionId();
				siteId = subscription.getGroupId();

				setContentType(
					() -> {
						DTOConverter<?, ?> dtoConverter =
							_dtoConverterRegistry.getDTOConverter(
								subscription.getClassName());

						if (dtoConverter == null) {
							return subscription.getClassName();
						}

						return dtoConverter.getContentType();
					});
			}
		};
	}

	@Reference
	private DTOConverterRegistry _dtoConverterRegistry;

	@Reference
	private SubscriptionLocalService _subscriptionLocalService;

}
